import type TransformingNetworkClient from '../../../communication/TransformingNetworkClient';
import type Page from '../../../data/page/Page';
import { type SubscriptionData } from '../../../data/subscriptions/data';
import type Subscription from '../../../data/subscriptions/Subscription';
import type Callback from '../../../types/Callback';
import Binder from '../../Binder';
import { type CancelParameters, type CreateParameters, type GetParameters, type IterateParameters, type PageParameters, type UpdateParameters } from './parameters';
export default class CustomerSubscriptionsBinder extends Binder<SubscriptionData, Subscription> {
    protected readonly networkClient: TransformingNetworkClient;
    constructor(networkClient: TransformingNetworkClient);
    /**
     * With subscriptions, you can schedule recurring payments to take place at regular intervals.
     *
     * For example, by simply specifying an `amount` and an `interval`, you can create an endless subscription to charge a monthly fee, until you cancel the subscription.
     *
     * Or, you could use the `times` parameter to only charge a limited number of times, for example to split a big transaction in multiple parts.
     *
     * A few example usages:
     *
     * -   `amount[currency]="EUR" amount[value]="5.00" interval="2 weeks"` Your consumer will be charged €5 once every two weeks.
     * -   `amount[currency]="EUR" amount[value]="20.00" interval="1 day" times=5` Your consumer will be charged €20 every day, for five consecutive days.
     * -   `amount[currency]="EUR" amount[value]="10.00" interval="1 month" startDate="2018-04-30"` Your consumer will be charged €10 on the last day of each month, starting in April 2018.
     *
     * @since 1.3.2
     * @see https://docs.mollie.com/reference/v2/subscriptions-api/create-subscription
     */
    create(parameters: CreateParameters): Promise<Subscription>;
    create(parameters: CreateParameters, callback: Callback<Subscription>): void;
    /**
     * Retrieve a subscription by its ID and its customer's ID.
     *
     * @since 1.3.2
     * @see https://docs.mollie.com/reference/v2/subscriptions-api/get-subscription
     */
    get(id: string, parameters: GetParameters): Promise<Subscription>;
    get(id: string, parameters: GetParameters, callback: Callback<Subscription>): void;
    /**
     * Retrieve all subscriptions of a customer.
     *
     * @since 3.0.0
     * @see https://docs.mollie.com/reference/v2/subscriptions-api/list-subscriptions
     */
    page(parameters: PageParameters): Promise<Page<Subscription>>;
    page(parameters: PageParameters, callback: Callback<Page<Subscription>>): void;
    /**
     * Retrieve all subscriptions of a customer.
     *
     * @since 3.6.0
     * @see https://docs.mollie.com/reference/v2/subscriptions-api/list-subscriptions
     */
    iterate(parameters: IterateParameters): import("../../../plumbing/iteration/HelpfulIterator").default<Subscription>;
    /**
     * Some fields of a subscription can be updated by calling `PATCH` on the resource endpoint. Each field is optional.
     *
     * You cannot update a canceled subscription.
     *
     * @since 2.0.0
     * @see https://docs.mollie.com/reference/v2/subscriptions-api/update-subscription
     */
    update(id: string, parameters: UpdateParameters): Promise<Subscription>;
    update(id: string, parameters: UpdateParameters, callback: Callback<Subscription>): void;
    /**
     * A subscription can be canceled any time by calling `DELETE` on the resource endpoint.
     *
     * @since 1.3.2
     * @see https://docs.mollie.com/reference/v2/subscriptions-api/cancel-subscription
     */
    cancel(id: string, parameters: CancelParameters): Promise<Subscription>;
    cancel(id: string, parameters: CancelParameters, callback: Callback<Subscription>): void;
}
